intelmq.bots.outputs.amqptopic package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.outputs.amqptopic package

## Submodules

## intelmq.bots.outputs.amqptopic.output module

class `intelmq.bots.outputs.amqptopic.output.` `AMQPTopicOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  Send events to an AMQP topic exchange. Requires the pika python library

  `connect_server`()
  `connection_attempts`: int = 3
  `connection_heartbeat`: int = 3600
  `connection_host`: str = '127.0.0.1'
  `connection_port`: int = 5672
  `connection_vhost`: str = None
  `content_type`: str = 'application/json'
  `delivery_mode`: int = 2
  `exchange_durable`: bool = True
  `exchange_name`: str = None
  `exchange_type`: str = 'topic'
  `format_routing_key`: bool = False
  `init`()
  `keep_raw_field`: bool = False
  `message_hierarchical_output`: bool = False
  `message_jsondict_as_string`: bool = False
  `message_with_type`: bool = False
  `password`: str = None
  `process`()

    Stop the Bot if cannot connect to AMQP Server after the defined connection attempts

  `require_confirmation`: bool = True
  `routing_key`: str = None
  `shutdown`()
  `single_key`: bool = False
  `use_ssl` = False
  `username` = None

`intelmq.bots.outputs.amqptopic.output.` `BOT`

  alias of `intelmq.bots.outputs.amqptopic.output.AMQPTopicOutputBot`

## Module contents